@@ -485,7 +485,56 @@ def is_valid_trade_time(instid, curtime):
         print("is_valid_trade_time Error:", e.__traceback__.tb_lineno,e)
         return None
 
+@assert_auth
+def get_product_spot_price(symbol, start_date, end_date):
+    try:
+        if isinstance(start_date, datetime):
+            start_date = start_date.strftime('%Y-%m-%d')
+        elif isinstance(start_date, str):
+            if len(start_date) != 10 or not is_valid_date(start_date):
+                print('Invalid start_date')
+                return None
+        if isinstance(end_date, datetime) :
+            end_date = end_date.strftime('%Y-%m-%d')
+        elif isinstance(end_date, str):
+            if len(end_date) != 10 or not is_valid_date(end_date):
+                print('Invalid end_date')
+                return None
+        return qedataClient.instance()('get_product_spot_price', **locals())
+    except Exception as e:
+        print("get_product_spot_price Error:", e.__traceback__.tb_lineno,e)
+        return None
 
+@assert_auth
+def get_product_invent_orders(symbol, start_date, end_date):
+    try:
+        if isinstance(start_date, datetime):
+            start_date = start_date.strftime('%Y-%m-%d')
+        elif isinstance(start_date, str):
+            if len(start_date) != 10 or not is_valid_date(start_date):
+                print('Invalid start_date')
+                return None
+        if isinstance(end_date, datetime):
+            end_date = end_date.strftime('%Y-%m-%d')
+        elif isinstance(end_date, str):
+            if len(end_date) != 10 or not is_valid_date(end_date):
+                print('Invalid end_date')
+                return None
+        return qedataClient.instance()('get_product_invent_orders', **locals())
+    except Exception as e:
+        print("get_product_invent_orders Error:", e.__traceback__.tb_lineno,e)
+        return None
+
+
+
+#########################algo trades#####################################
+@assert_auth
+def get_package_address(plugin, plat, version, macaddr):
+        return qedataClient.instance()('get_package_address', **locals())
+
+@assert_auth
+def get_plugin_permission(plugin, plat, version, macaddr, key, signval):
+        return qedataClient.instance()('get_plugin_permission', **locals())
         
 ##############################stratmarket############################
 def sm_get_clone_strat_list():
@@ -516,6 +565,7 @@ def sm_get_clone_strat_position(strats:list):
     
 
 
+
 __all__ = []
 
 def _collect_func():
