@@ -15,7 +15,10 @@ stratlist=(qesdk.sm_get_clone_strat_list())
 print('strats',stratlist)
 if stratlist and isinstance(stratlist,list) and len(stratlist) > 0:
     print(qesdk.sm_get_clone_strat_position(stratlist))
-'''    
+'''
+df = qesdk.get_product_invent_orders('CU', '2023-02-01','2023-02-14')
+print(df)
+    
 #qesdk.auth('quantease','$1$$k7yjPQKv8AJuZERDA.eQX.')
 #df = qesdk.get_realtime_minute_prices(['AU2212.SFE','AG2301.SFE'])
 #print(df)
